/*
 *   casmi
 *   http://casmi.github.com/
 *   Copyright (C) 2011, Xcoo, Inc.
 *
 *  casmi is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package casmi.graphics.color;

/**
 * ColorSet by keywords.
 * <p>
 * http://www.w3.org/TR/css3-color/
 *
 * @author K. Nishimura
 *
 * @see casmi.graphics.color.Color
 */
public enum ColorSet {

    /** (240, 248, 255). */
    ALICE_BLUE,

    /** (250, 235, 215). */
    ANTIQUE_WHITE,

    /** (0, 255, 255). */
    AQUA,

    /** (127, 255, 212). */
    AQUAMARINE,

    /** (240, 255, 255). */
    AZURE,

    /** (245, 245, 220). */
    BEIGE,

    /** (255, 228, 196). */
    BISQUE,

    /** (0, 0, 0). */
    BLACK,

    /** (255, 235, 205). */
    BLANCHED_ALMOND,

    /** (0, 0, 255). */
    BLUE,

    /** (138, 43, 226). */
    BLUE_VIOLET,

    /** (165, 42, 42). */
    BROWN,

    /** (222, 184, 135). */
    BURLY_WOOD,

    /** (95, 158, 160). */
    CADET_BLUE,

    /** (127, 255, 0). */
    CHARTREUSE,

    /** (210, 105, 30). */
    CHOCOLATE,

    /** (255, 127, 80). */
    CORAL,

    /** (100, 149, 237). */
    CORNFLOWER_BLUE,

    /** (255, 248, 220). */
    CORNSILK,

    /** (220, 20, 60). */
    CRIMSON,

    /** (0, 255, 255). */
    CYAN,

    /** (0, 0, 139). */
    DARK_BLUE,

    /** (0, 139, 139). */
    DARK_CYAN,

    /** (184, 134, 11). */
    DARK_GOLDENROD,

    /** (169, 169, 169). */
    DARK_GRAY,

    /** (0, 100, 0). */
    DARK_GREEN,

    /** (169, 169, 169). */
    DARK_GREY,

    /** (189, 183, 107). */
    DARK_KHAKI,

    /** (139, 0, 139). */
    DARK_MAGENTA,

    /** (85, 107, 47). */
    DARK_OLIVE_GREEN,

    /** (255, 140, 0). */
    DARK_ORANGE,

    /** (153, 50, 204). */
    DARK_ORCHID,

    /** (139, 0, 0). */
    DARK_RED,

    /** (233, 150, 122). */
    DARK_SALMON,

    /** (143, 188, 143). */
    DARK_SEA_GREEN,

    /** (72, 61, 139). */
    DARK_SLATE_BLUE,

    /** (47, 79, 79). */
    DARK_SLATE_GRAY,

    /** (47, 79, 79). */
    DARK_SLATE_GREY,

    /** (0, 206, 209). */
    DARK_TURQUOISE,

    /** (148, 0, 211). */
    DARK_VIOLET,

    /** (255, 20, 147). */
    DEEP_PINK,

    /** (0, 191, 255). */
    DEEP_SKY_BLUE,

    /** (105, 105, 105). */
    DIM_GRAY,

    /** (105, 105, 105). */
    DIM_GREY,

    /** (30, 144, 255). */
    DODGER_BLUE,

    /** (178, 34, 34). */
    FIREBRICK,

    /** (255, 250, 240). */
    FLORAL_WHITE,

    /** (34, 139, 34). */
    FOREST_GREEN,

    /** (255, 0, 255). */
    FUCHSIA,

    /** (220, 220, 220). */
    GAINSBORO,

    /** (248, 248, 255). */
    GHOST_WHITE,

    /** (255, 215, 0). */
    GOLD,

    /** (218, 165, 32). */
    GOLDENROD,

    /** (128, 128, 128). */
    GRAY,

    /** (0, 128, 0). */
    GREEN,

    /** (173, 255, 47). */
    GREEN_YELLOW,

    /** (128, 128, 128). */
    GREY,

    /** (240, 255, 240). */
    HONEYDEW,

    /** (255, 105, 180). */
    HOT_PINK,

    /** (205, 92, 92). */
    INDIAN_RED,

    /** (75, 0, 130). */
    INDIGO,

    /** (255, 255, 240). */
    IVORY,

    /** (240, 230, 140). */
    KHAKI,

    /** (230, 230, 250). */
    LAVENDER,

    /** (255, 240, 245). */
    LAVENDER_BLUSH,

    /** (124, 252, 0). */
    LAWN_GREEN,

    /** (255, 250, 205). */
    LEMON_CHIFFON,

    /** (173, 216, 230). */
    LIGHT_BLUE,

    /** (240, 128, 128). */
    LIGHT_CORAL,

    /** (224, 255, 255). */
    LIGHT_CYAN,

    /** (250, 250, 210). */
    LIGHT_GOLDENROD_YELLOW,

    /** (211, 211, 211). */
    LIGHT_GRAY,

    /** (144, 238, 144). */
    LIGHT_GREEN,

    /** (211, 211, 211). */
    LIGHT_GREY,

    /** (255, 182, 193). */
    LIGHT_PINK,

    /** (255, 160, 122). */
    LIGHT_SALMON,

    /** (32, 178, 170). */
    LIGHT_SEA_GREEN,

    /** (135, 206, 250). */
    LIGHT_SKY_BLUE,

    /** (119, 136, 153). */
    LIGHT_SLATE_GRAY,

    /** (119, 136, 153). */
    LIGHT_SLATE_GREY,

    /** (176, 196, 222). */
    LIGHT_STEEL_BLUE,

    /** (255, 255, 224). */
    LIGHT_YELLOW,

    /** (0, 255, 0). */
    LIME,

    /** (50, 205, 50). */
    LIME_GREEN,

    /** (250, 240, 230). */
    LINEN,

    /** (255, 0, 255). */
    MAGENTA,

    /** (128, 0, 0). */
    MAROON,

    /** (102, 205, 170). */
    MEDIUM_AQUAMARINE,

    /** (0, 0, 205). */
    MEDIUM_BLUE,

    /** (186, 85, 211). */
    MEDIUM_ORCHID,

    /** (147, 112, 219). */
    MEDIUM_PURPLE,

    /** (60, 179, 114). */
    MEDIUM_SEA_GREEN,

    /** (123, 104, 238). */
    MEDIUM_SLATE_BLUE,

    /** (0, 250, 154). */
    MEDIUM_SPRING_GREEN,

    /** (72, 209, 204). */
    MEDIUM_TURQUOISE,

    /** (199, 21, 133). */
    MEDIUM_VIOLET_RED,

    /** (25, 25, 112). */
    MIDNIGHT_BLUE,

    /** (245, 255, 250). */
    MINT_CREAM,

    /** (255, 228, 225). */
    MISTY_ROSE,

    /** (255, 228, 181). */
    MOCCASIN,

    /** (255, 222, 173). */
    NAVAJO_WHITE,

    /** (0, 0, 128). */
    NAVY,

    /** (253, 245, 230). */
    OLD_LACE,

    /** (128, 128, 0). */
    OLIVE,

    /** (107, 142, 35). */
    OLIVE_DRAB,

    /** (255, 165, 0). */
    ORANGE,

    /** (255, 69, 0). */
    ORANGE_RED,

    /** (218, 112, 214). */
    ORCHID,

    /** (238, 232, 170). */
    PALE_GOLDENROD,

    /** (152, 251, 154). */
    PALE_GREEN,

    /** (175, 238, 238). */
    PALE_TURQUOISE,

    /** (219, 112, 147). */
    PALE_VIOLET_RED,

    /** (255, 239, 213). */
    PAPAYA_WHIP,

    /** (255, 218, 185). */
    PEACH_PUFF,

    /** (205, 133, 63). */
    PERU,

    /** (255, 192, 203). */
    PINK,

    /** (221, 160, 221). */
    PLUM,

    /** (176, 224, 230). */
    POWDER_BLUE,

    /** (128, 0, 128). */
    PURPLE,

    /** (255, 0, 0). */
    RED,

    /** (188, 136, 153). */
    ROSY_BROWN,

    /** (65, 105, 255). */
    ROYAL_BLUE,

    /** (139, 69, 19). */
    SADDLE_BROWN,

    /** (250, 128, 114). */
    SALMON,

    /** (244, 164, 96). */
    SANDY_BROWN,

    /** (46, 139, 87). */
    SEA_GREEN,

    /** (255, 245, 238) */
    SEA_SHELL,

    /** (160, 82, 45) */
    SIENNA,

    /** (192, 192, 192) */
    SILVER,

    /** (135, 206, 235) */
    SKY_BLUE,

    /** (106, 90, 205) */
    SLATE_BLUE,

    /** (112, 128, 144). */
    SLATE_GRAY,

    /** (112, 128, 144). */
    SLATE_GREY,

    /** (255, 250, 250). */
    SNOW,

    /** (0, 255, 127). */
    SPRING_GREEN,

    /** (70, 130, 180). */
    STEEL_BLUE,

    /** (210, 180, 140). */
    TAN,

    /** (0, 128, 128). */
    TEAL,

    /** (216, 191, 216). */
    THISTLE,

    /** (255, 99, 71). */
    TOMATO,

    /** (64, 224, 208). */
    TURQUOISE,

    /** (238, 130, 238). */
    VIOLET,

    /** (245, 222, 179). */
    WHEAT,

    /** (255, 255, 255). */
    WHITE,

    /** (245, 245, 245). */
    WHITE_SMOKE,

    /** (255, 255, 0). */
    YELLOW,

    /** (154, 205, 50). */
    YELLOW_GREEN;

    /**
     * Returns RGB values from ColorSet.
     *
     * @param colorSet
     *            The ColorSet.
     *
     * @return
     *            Array of RGB values from 0 to 255.
     */
    static final int[] getRGB(ColorSet colorSet) {
        int[] ret = {0, 0, 0};

        switch (colorSet) {
        case ALICE_BLUE:
            ret[0] = 240;
            ret[1] = 248;
            ret[2] = 255;
            break;
        case ANTIQUE_WHITE:
            ret[0] = 250;
            ret[1] = 235;
            ret[2] = 215;
            break;
        case AQUA:
            ret[0] = 0;
            ret[1] = 255;
            ret[2] = 255;
            break;
        case AQUAMARINE:
            ret[0] = 127;
            ret[1] = 255;
            ret[2] = 212;
            break;
        case AZURE:
            ret[0] = 240;
            ret[1] = 255;
            ret[2] = 255;
            break;
        case BEIGE:
            ret[0] = 245;
            ret[1] = 245;
            ret[2] = 220;
            break;
        case BISQUE:
            ret[0] = 255;
            ret[1] = 228;
            ret[2] = 196;
            break;
        case BLACK:
            ret[0] = 0;
            ret[1] = 0;
            ret[2] = 0;
            break;
        case BLANCHED_ALMOND:
            ret[0] = 255;
            ret[1] = 235;
            ret[2] = 205;
            break;
        case BLUE:
            ret[0] = 0;
            ret[1] = 0;
            ret[2] = 255;
            break;
        case BLUE_VIOLET:
            ret[0] = 138;
            ret[1] = 43;
            ret[2] = 226;
            break;
        case BROWN:
            ret[0] = 165;
            ret[1] = 42;
            ret[2] = 42;
            break;
        case BURLY_WOOD:
            ret[0] = 222;
            ret[1] = 184;
            ret[2] = 135;
            break;
        case CADET_BLUE:
            ret[0] = 95;
            ret[1] = 158;
            ret[2] = 160;
            break;
        case CHARTREUSE:
            ret[0] = 127;
            ret[1] = 255;
            ret[2] = 0;
            break;
        case CHOCOLATE:
            ret[0] = 210;
            ret[1] = 105;
            ret[2] = 30;
            break;
        case CORAL:
            ret[0] = 255;
            ret[1] = 127;
            ret[2] = 80;
            break;
        case CORNFLOWER_BLUE:
            ret[0] = 100;
            ret[1] = 149;
            ret[2] = 237;
            break;
        case CORNSILK:
            ret[0] = 255;
            ret[1] = 248;
            ret[2] = 220;
            break;
        case CRIMSON:
            ret[0] = 220;
            ret[1] = 20;
            ret[2] = 60;
            break;
        case CYAN:
            ret[0] = 0;
            ret[1] = 255;
            ret[2] = 255;
            break;
        case DARK_BLUE:
            ret[0] = 0;
            ret[1] = 0;
            ret[2] = 139;
            break;
        case DARK_CYAN:
            ret[0] = 0;
            ret[1] = 139;
            ret[2] = 139;
            break;
        case DARK_GOLDENROD:
            ret[0] = 184;
            ret[1] = 134;
            ret[2] = 11;
            break;
        case DARK_GRAY:
            ret[0] = 169;
            ret[1] = 169;
            ret[2] = 169;
            break;
        case DARK_GREEN:
            ret[0] = 0;
            ret[1] = 100;
            ret[2] = 0;
            break;
        case DARK_GREY:
            ret[0] = 169;
            ret[1] = 169;
            ret[2] = 169;
            break;
        case DARK_KHAKI:
            ret[0] = 189;
            ret[1] = 183;
            ret[2] = 107;
            break;
        case DARK_MAGENTA:
            ret[0] = 139;
            ret[1] = 0;
            ret[2] = 139;
            break;
        case DARK_OLIVE_GREEN:
            ret[0] = 85;
            ret[1] = 107;
            ret[2] = 47;
            break;
        case DARK_ORANGE:
            ret[0] = 255;
            ret[1] = 140;
            ret[2] = 0;
            break;
        case DARK_ORCHID:
            ret[0] = 153;
            ret[1] = 50;
            ret[2] = 204;
            break;
        case DARK_RED:
            ret[0] = 139;
            ret[1] = 0;
            ret[2] = 0;
            break;
        case DARK_SALMON:
            ret[0] = 233;
            ret[1] = 150;
            ret[2] = 122;
            break;
        case DARK_SEA_GREEN:
            ret[0] = 143;
            ret[1] = 188;
            ret[2] = 143;
            break;
        case DARK_SLATE_BLUE:
            ret[0] = 72;
            ret[1] = 61;
            ret[2] = 139;
            break;
        case DARK_SLATE_GRAY:
            ret[0] = 47;
            ret[1] = 79;
            ret[2] = 79;
            break;
        case DARK_TURQUOISE:
            ret[0] = 0;
            ret[1] = 206;
            ret[2] = 209;
            break;
        case DARK_VIOLET:
            ret[0] = 148;
            ret[1] = 0;
            ret[2] = 211;
            break;
        case DEEP_PINK:
            ret[0] = 255;
            ret[1] = 20;
            ret[2] = 147;
            break;
        case DEEP_SKY_BLUE:
            ret[0] = 0;
            ret[1] = 191;
            ret[2] = 255;
            break;
        case DIM_GRAY:
            ret[0] = 105;
            ret[1] = 105;
            ret[2] = 105;
            break;
        case DIM_GREY:
            ret[0] = 105;
            ret[1] = 105;
            ret[2] = 105;
            break;
        case DODGER_BLUE:
            ret[0] = 30;
            ret[1] = 144;
            ret[2] = 255;
            break;
        case FIREBRICK:
            ret[0] = 178;
            ret[1] = 34;
            ret[2] = 34;
            break;
        case FLORAL_WHITE:
            ret[0] = 255;
            ret[1] = 250;
            ret[2] = 240;
            break;
        case FOREST_GREEN:
            ret[0] = 34;
            ret[1] = 139;
            ret[2] = 34;
            break;
        case FUCHSIA:
            ret[0] = 255;
            ret[1] = 0;
            ret[2] = 255;
            break;
        case GAINSBORO:
            ret[0] = 220;
            ret[1] = 220;
            ret[2] = 220;
            break;
        case GHOST_WHITE:
            ret[0] = 248;
            ret[1] = 248;
            ret[2] = 255;
            break;
        case GOLD:
            ret[0] = 255;
            ret[1] = 215;
            ret[2] = 0;
            break;
        case GOLDENROD:
            ret[0] = 218;
            ret[1] = 165;
            ret[2] = 32;
            break;
        case GRAY:
            ret[0] = 128;
            ret[1] = 128;
            ret[2] = 128;
            break;
        case GREEN:
            ret[0] = 0;
            ret[1] = 128;
            ret[2] = 0;
            break;
        case GREEN_YELLOW:
            ret[0] = 173;
            ret[1] = 255;
            ret[2] = 47;
            break;
        case GREY:
            ret[0] = 128;
            ret[1] = 128;
            ret[2] = 128;
            break;
        case HONEYDEW:
            ret[0] = 240;
            ret[1] = 255;
            ret[2] = 240;
            break;
        case HOT_PINK:
            ret[0] = 255;
            ret[1] = 105;
            ret[2] = 180;
            break;
        case INDIAN_RED:
            ret[0] = 205;
            ret[1] = 92;
            ret[2] = 92;
            break;
        case INDIGO:
            ret[0] = 75;
            ret[1] = 0;
            ret[2] = 130;
            break;
        case IVORY:
            ret[0] = 255;
            ret[1] = 255;
            ret[2] = 240;
            break;
        case KHAKI:
            ret[0] = 240;
            ret[1] = 230;
            ret[2] = 140;
            break;
        case LAVENDER:
            ret[0] = 230;
            ret[1] = 230;
            ret[2] = 250;
            break;
        case LAVENDER_BLUSH:
            ret[0] = 255;
            ret[1] = 240;
            ret[2] = 245;
            break;
        case LAWN_GREEN:
            ret[0] = 124;
            ret[1] = 252;
            ret[2] = 0;
            break;
        case LEMON_CHIFFON:
            ret[0] = 255;
            ret[1] = 250;
            ret[2] = 205;
            break;
        case LIGHT_BLUE:
            ret[0] = 173;
            ret[1] = 216;
            ret[2] = 230;
            break;
        case LIGHT_CORAL:
            ret[0] = 240;
            ret[1] = 128;
            ret[2] = 128;
            break;
        case LIGHT_CYAN:
            ret[0] = 224;
            ret[1] = 255;
            ret[2] = 255;
            break;
        case LIGHT_GOLDENROD_YELLOW:
            ret[0] = 250;
            ret[1] = 250;
            ret[2] = 210;
            break;
        case LIGHT_GRAY:
            ret[0] = 211;
            ret[1] = 211;
            ret[2] = 211;
            break;
        case LIGHT_GREEN:
            ret[0] = 144;
            ret[1] = 238;
            ret[2] = 144;
            break;
        case LIGHT_GREY:
            ret[0] = 211;
            ret[1] = 211;
            ret[2] = 211;
            break;
        case LIGHT_PINK:
            ret[0] = 255;
            ret[1] = 182;
            ret[2] = 193;
            break;
        case LIGHT_SALMON:
            ret[0] = 255;
            ret[1] = 160;
            ret[2] = 122;
            break;
        case LIGHT_SEA_GREEN:
            ret[0] = 32;
            ret[1] = 178;
            ret[2] = 170;
            break;
        case LIGHT_SKY_BLUE:
            ret[0] = 135;
            ret[1] = 206;
            ret[2] = 250;
            break;
        case LIGHT_SLATE_GRAY:
            ret[0] = 119;
            ret[1] = 136;
            ret[2] = 153;
            break;
        case LIGHT_SLATE_GREY:
            ret[0] = 119;
            ret[1] = 136;
            ret[2] = 153;
            break;
        case LIGHT_STEEL_BLUE:
            ret[0] = 176;
            ret[1] = 196;
            ret[2] = 222;
            break;
        case LIGHT_YELLOW:
            ret[0] = 255;
            ret[1] = 255;
            ret[2] = 224;
            break;
        case LIME:
            ret[0] = 0;
            ret[1] = 255;
            ret[2] = 0;
            break;
        case LIME_GREEN:
            ret[0] = 50;
            ret[1] = 205;
            ret[2] = 50;
            break;
        case LINEN:
            ret[0] = 250;
            ret[1] = 240;
            ret[2] = 230;
            break;
        case MAGENTA:
            ret[0] = 255;
            ret[1] = 0;
            ret[2] = 255;
            break;
        case MAROON:
            ret[0] = 128;
            ret[1] = 0;
            ret[2] = 0;
            break;
        case MEDIUM_AQUAMARINE:
            ret[0] = 102;
            ret[1] = 205;
            ret[2] = 170;
            break;
        case MEDIUM_BLUE:
            ret[0] = 0;
            ret[1] = 0;
            ret[2] = 205;
            break;
        case MEDIUM_ORCHID:
            ret[0] = 186;
            ret[1] = 85;
            ret[2] = 211;
            break;
        case MEDIUM_PURPLE:
            ret[0] = 147;
            ret[1] = 112;
            ret[2] = 219;
            break;
        case MEDIUM_SEA_GREEN:
            ret[0] = 60;
            ret[1] = 179;
            ret[2] = 113;
            break;
        case MEDIUM_SLATE_BLUE:
            ret[0] = 123;
            ret[1] = 104;
            ret[2] = 238;
            break;
        case MEDIUM_SPRING_GREEN:
            ret[0] = 0;
            ret[1] = 250;
            ret[2] = 154;
            break;
        case MEDIUM_TURQUOISE:
            ret[0] = 72;
            ret[1] = 209;
            ret[2] = 204;
            break;
        case MEDIUM_VIOLET_RED:
            ret[0] = 199;
            ret[1] = 21;
            ret[2] = 133;
            break;
        case MIDNIGHT_BLUE:
            ret[0] = 25;
            ret[1] = 25;
            ret[2] = 112;
            break;
        case MINT_CREAM:
            ret[0] = 245;
            ret[1] = 255;
            ret[2] = 250;
            break;
        case MISTY_ROSE:
            ret[0] = 255;
            ret[1] = 228;
            ret[2] = 225;
            break;
        case MOCCASIN:
            ret[0] = 255;
            ret[1] = 228;
            ret[2] = 181;
            break;
        case NAVAJO_WHITE:
            ret[0] = 255;
            ret[1] = 222;
            ret[2] = 173;
            break;
        case NAVY:
            ret[0] = 0;
            ret[1] = 0;
            ret[2] = 128;
            break;
        case OLD_LACE:
            ret[0] = 253;
            ret[1] = 245;
            ret[2] = 230;
            break;
        case OLIVE:
            ret[0] = 128;
            ret[1] = 128;
            ret[2] = 0;
            break;
        case OLIVE_DRAB:
            ret[0] = 107;
            ret[1] = 142;
            ret[2] = 35;
            break;
        case ORANGE:
            ret[0] = 255;
            ret[1] = 165;
            ret[2] = 0;
            break;
        case ORANGE_RED:
            ret[0] = 255;
            ret[1] = 69;
            ret[2] = 0;
            break;
        case ORCHID:
            ret[0] = 218;
            ret[1] = 112;
            ret[2] = 214;
            break;
        case PALE_GOLDENROD:
            ret[0] = 238;
            ret[1] = 232;
            ret[2] = 170;
            break;
        case PALE_GREEN:
            ret[0] = 152;
            ret[1] = 251;
            ret[2] = 152;
            break;
        case PALE_TURQUOISE:
            ret[0] = 175;
            ret[1] = 238;
            ret[2] = 238;
            break;
        case PALE_VIOLET_RED:
            ret[0] = 219;
            ret[1] = 112;
            ret[2] = 147;
            break;
        case PAPAYA_WHIP:
            ret[0] = 255;
            ret[1] = 239;
            ret[2] = 213;
            break;
        case PEACH_PUFF:
            ret[0] = 255;
            ret[1] = 218;
            ret[2] = 185;
            break;
        case PERU:
            ret[0] = 205;
            ret[1] = 133;
            ret[2] = 63;
            break;
        case PINK:
            ret[0] = 255;
            ret[1] = 192;
            ret[2] = 203;
            break;
        case PLUM:
            ret[0] = 221;
            ret[1] = 160;
            ret[2] = 221;
            break;
        case POWDER_BLUE:
            ret[0] = 176;
            ret[1] = 224;
            ret[2] = 230;
            break;
        case PURPLE:
            ret[0] = 128;
            ret[1] = 0;
            ret[2] = 128;
            break;
        case RED:
            ret[0] = 255;
            ret[1] = 0;
            ret[2] = 0;
            break;
        case ROSY_BROWN:
            ret[0] = 188;
            ret[1] = 136;
            ret[2] = 153;
            break;
        case ROYAL_BLUE:
            ret[0] = 65;
            ret[1] = 105;
            ret[2] = 255;
            break;
        case SADDLE_BROWN:
            ret[0] = 139;
            ret[1] = 69;
            ret[2] = 19;
            break;
        case SALMON:
            ret[0] = 250;
            ret[1] = 128;
            ret[2] = 114;
            break;
        case SANDY_BROWN:
            ret[0] = 244;
            ret[1] = 164;
            ret[2] = 96;
            break;
        case SEA_GREEN:
            ret[0] = 46;
            ret[1] = 139;
            ret[2] = 87;
            break;
        case SEA_SHELL:
            ret[0] = 255;
            ret[1] = 245;
            ret[2] = 238;
            break;
        case SIENNA:
            ret[0] = 160;
            ret[1] = 82;
            ret[2] = 45;
            break;
        case SILVER:
            ret[0] = 192;
            ret[1] = 192;
            ret[2] = 192;
            break;
        case SKY_BLUE:
            ret[0] = 135;
            ret[1] = 206;
            ret[2] = 235;
            break;
        case SLATE_BLUE:
            ret[0] = 106;
            ret[1] = 90;
            ret[2] = 205;
            break;
        case SLATE_GRAY:
            ret[0] = 112;
            ret[1] = 128;
            ret[2] = 144;
            break;
        case SLATE_GREY:
            ret[0] = 112;
            ret[1] = 128;
            ret[2] = 144;
            break;
        case SNOW:
            ret[0] = 255;
            ret[1] = 250;
            ret[2] = 250;
            break;
        case SPRING_GREEN:
            ret[0] = 0;
            ret[1] = 255;
            ret[2] = 127;
            break;
        case STEEL_BLUE:
            ret[0] = 70;
            ret[1] = 130;
            ret[2] = 180;
            break;
        case TAN:
            ret[0] = 210;
            ret[1] = 180;
            ret[2] = 140;
            break;
        case TEAL:
            ret[0] = 0;
            ret[1] = 128;
            ret[2] = 128;
            break;
        case THISTLE:
            ret[0] = 216;
            ret[1] = 191;
            ret[2] = 216;
            break;
        case TOMATO:
            ret[0] = 255;
            ret[1] = 99;
            ret[2] = 71;
            break;
        case TURQUOISE:
            ret[0] = 64;
            ret[1] = 224;
            ret[2] = 208;
            break;
        case VIOLET:
            ret[0] = 238;
            ret[1] = 130;
            ret[2] = 238;
            break;
        case WHEAT:
            ret[0] = 245;
            ret[1] = 222;
            ret[2] = 179;
            break;
        case WHITE:
            ret[0] = 255;
            ret[1] = 255;
            ret[2] = 255;
            break;
        case WHITE_SMOKE:
            ret[0] = 245;
            ret[1] = 245;
            ret[2] = 245;
            break;
        case YELLOW:
            ret[0] = 255;
            ret[1] = 255;
            ret[2] = 0;
            break;
        case YELLOW_GREEN:
            ret[0] = 154;
            ret[1] = 205;
            ret[2] = 50;
            break;
        default:
            break;
        }

        return ret;
    }
}
